/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of gui toolkit related functions.
 *
 * This is the header file of gui toolkit related functions.
 * Function definition here is independent of the platform.
 * When you don't define WIN32 macro, platform independent function
 * definitions will be linked to the Xlib related gui toolkit
 * ( RLx.h and related files ) by #define keyword and linking with 
 * "rlib_x" prefixed files.
 *
 * $Id: RLgt.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $
 */

#ifndef ___RL_GT_H_INCLUDED_
#define ___RL_GT_H_INCLUDED_


#ifndef WIN32

#include "RLx.h"

#define RLgtApp                      RLXApp
#define RL_GT_MAX_RGB                255
#define Point                        XPoint

#define rlib_gt_initialize              rlib_x_initialize
#define rlib_gt_get_width               rlib_x_get_width
#define rlib_gt_get_height              rlib_x_get_height
#define rlib_gt_enable_dropframe        rlib_x_enable_dropframe
#define rlib_gt_disable_dropframe       rlib_x_disable_dropframe
#define rlib_gt_is_dropframe_enabled    rlib_x_is_dropframe_enabled
#define rlib_gt_set_fps                 rlib_x_set_fps
#define rlib_gt_set_update_func         rlib_x_set_update_func
#define rlib_gt_set_draw_func           rlib_x_set_draw_func
#define rlib_gt_set_cleanup_func        rlib_x_set_cleanup_func
#define rlib_gt_autorepeat_on           rlib_x_autorepeat_on
#define rlib_gt_autorepeat_off          rlib_x_autorepeat_off
#define rlib_gt_autorepeat_set          rlib_x_autorepeat_set
#define rlib_gt_get_autorepeat_previous rlib_x_get_autorepeat_previous
#define rlib_gt_get_autorepeat          rlib_x_get_autorepeat
#define rlib_gt_start                   rlib_x_start
#define rlib_gt_stop                    rlib_x_stop
#define rlib_gt_cleanup                 rlib_x_cleanup
#define rlib_gt_get_exitcode            rlib_x_get_exitcode
#define rlib_gt_sync                    rlib_x_sync
#define rlib_gt_debug_on                rlib_x_debug_on
#define rlib_gt_debug_off               rlib_x_debug_off
#define rlib_gt_is_debug_on             rlib_x_is_debug_on
#define rlib_gt_mouse_moved             rlib_x_mouse_moved
#define rlib_gt_mouse_query_position    rlib_x_mouse_query_position
#define rlib_gt_clear_event_handler     rlib_x_clear_event_handler
#define rlib_gt_process_event           rlib_x_process_event
#define rlib_gt_draw_image              rlib_x_draw_pixmap
#define rlib_gt_get_image_size          rlib_x_get_pixmap_size
#define rlib_gt_draw_point              rlib_x_draw_point
#define rlib_gt_draw_line               rlib_x_draw_line
#define rlib_gt_draw_lines              rlib_x_draw_lines
#define rlib_gt_draw_rectangle          rlib_x_draw_rectangle
#define rlib_gt_fill_rectangle          rlib_x_fill_rectangle
#define rlib_gt_draw_arc                rlib_x_draw_arc
#define rlib_gt_fill_arc                rlib_x_fill_arc

#endif /* WIN32 */


/*!
 * @brief Key code enumeration independent of the platform.
 */
typedef enum
{
	RL_GT_KEY_GUARD,
	RL_GT_KEY_UP,
	RL_GT_KEY_DOWN,
	RL_GT_KEY_LEFT,
	RL_GT_KEY_RIGHT,
	RL_GT_KEY_ESC,
	RL_GT_KEY_RETURN,
	RL_GT_KEY_SPACE,
	RL_GT_KEY_D,
	RL_GT_KEY_F,
	RL_GT_KEY_H,
	RL_GT_KEY_M,
	RL_GT_KEY_N,
	RL_GT_KEY_O,
	RL_GT_KEY_P,
	RL_GT_KEY_S,
	RL_GT_KEY_d,
	RL_GT_KEY_f,
	RL_GT_KEY_h,
	RL_GT_KEY_m,
	RL_GT_KEY_n,
	RL_GT_KEY_o,
	RL_GT_KEY_p,
	RL_GT_KEY_s
}
RLgtKey;


/*!
 * @brief Mouse button code enumeration independent of the platform.
 */
typedef enum
{
	RL_GT_MOUSE_GUARD,
	RL_GT_MOUSE_LEFT,
	RL_GT_MOUSE_MIDDLE,
	RL_GT_MOUSE_RIGHT
}
RLgtMouse;


/*!
 * @brief Event type.
 */
typedef enum
{
	RL_GT_EVENT_GUARD,
	RL_GT_KEY_PRESSED,
	RL_GT_KEY_RELEASED,
	RL_GT_MOUSE_MOVED,
	RL_GT_MOUSE_PRESSED,
	RL_GT_MOUSE_RELEASED
}
RLgtEventType;


/*!
 * @brief When you use rlib_gt_fill_polygon, specify one of the following.
 */
typedef enum
{
	RL_GT_POLYGON_CONVEX,
	RL_GT_POLYGON_NONCONVEX,
	RL_GT_POLYGON_COMPLEX
}
RLgtPolygonMode;


/*!
 * @brief When you use rlib_gt_load_image, specify on of the following.
 */
typedef enum
{
	RL_GT_USE_MASK,
	RL_GT_NO_MASK
}
RLgtMaskUsage;


#define RL_GT_LEFTTOP( index, app, x_center, y_center, x, y, image_w, image_h ) { \
\
        rlib_gt_get_image_size( ( app ), ( index ), &( image_w ), &( image_h ) ); \
        x = ( x_center ) - ( ( image_w ) / 2 ); \
        y = ( y_center ) - ( ( image_h ) / 2 ); \
}


#define RL_GT_DRAW_IMAGE( app, index, cx, cy ) { \
        int width;  \
        int height; \
        int lt_x;   \
        int lt_y;   \
\
        RL_GT_LEFTTOP( (index), (app), (cx), (cy), lt_x, lt_y, width, height ); \
        rlib_gt_draw_image( (app), (index), 0, 0, width, height, lt_x, lt_y ); \
}


int  rlib_gt_key_pressed( RLgtApp* app, RLgtKey key );
int  rlib_gt_key_released( RLgtApp* app, RLgtKey key );
int  rlib_gt_mouse_pressed( RLgtApp* app, RLgtMouse mouse, int* x, int* y );
int  rlib_gt_mouse_released( RLgtApp* app, RLgtMouse mouse, int* x, int* y );
int  rlib_gt_add_event_handler( RLgtApp* app, RLgtEventType type, int ( *callback )( void* ), void* data );
void rlib_gt_set_foreground_color( RLgtApp* app, unsigned int r, unsigned int g, unsigned int b );
void rlib_gt_set_background_color( RLgtApp* app, unsigned int r, unsigned int g, unsigned int b );
void rlib_gt_fill_polygon( RLgtApp* app, Point* points, int npoints, RLgtPolygonMode mode );
int  rlib_gt_load_image( RLgtApp* app, char* filename, int use_mask );


#endif /* ___RL_GT_H_INCLUDED_ */

/* End of RLgt.h */
