/*
 * Copyright (c) 2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of an explosion entity.
 *
 * "$Id: explosion.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#ifndef ___EXPLOSION_H_INCLUDED_
#define ___EXPLOSION_H_INCLUDED_

#include "RLgt.h"
#include "RLrect.h"


#define EXPLOSION_FPS_RATIO 1 /* ( 60.0 / 60.0 ) */
#define EXPLOSION_FRAME_COUNT_EFFECT ( 40 * EXPLOSION_FPS_RATIO )

#define EXPLOSION_IMAGE_NUM    4
#define EXPLOSION_IMAGE_SMALL  0
#define EXPLOSION_IMAGE_MEDIUM 1
#define EXPLOSION_IMAGE_LARGE  2
#define EXPLOSION_IMAGE_GIANT  3


/*!
 * @brief Explosion entity's data structure.
 */
typedef struct
{
	RLgtApp* gt_app;
	RLrect   screen;
	int      effect_explosion_frame_count;
	int*     image_index;
	int      is_exploding;
	double   screen_center_x;
	double   screen_center_y;
	double   px;
	double   py;
}
Explosion;


void explosion_init( Explosion* explosion, RLgtApp* app, RLrect* screen, int* image_index );
int  explosion_is_exploding( Explosion* explosion );
void explosion_update( Explosion* explosion, double center_x, double center_y );
void explosion_draw( Explosion* explosion );
void explosion_set_position( Explosion* explosion, double x, double y );


#define EXPLOSION_SCREEN_POSITION( explosion, x, y ) { \
        (x) = (explosion)->screen.lefttop_x + (explosion)->screen.width  / 2  + \
                (explosion)->px - (explosion)->screen_center_x; \
        (y) = (explosion)->screen.lefttop_y + (explosion)->screen.height / 2 + \
                (explosion)->py - (explosion)->screen_center_y; \
}


#endif /* ___EXPLOSION_H_INCLUDED_ */

/* End of explosion.h */
