/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of the module that handles map-data.
 *
 * "$Id: map.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#ifndef ___MAP_H_INCLUDED_
#define ___MAP_H_INCLUDED_


#include "RLgt.h"
#include "RLlist.h"
#include "RLrect.h"
#include "RLsound.h"
#include "entity.h"
#include "map_util.h"


#define MAP_MAX_LEVEL 3
#define MAP_MIN_LEVEL 0

#define MAP_MAX_BLOCKIMAGE_NUM 5 /* <=== must be MAP_MAX_LEVEL + 2 */
#define MAP_KEY_NUM   3

#define MAP_NORMAL_BLOCK  '#'
#define MAP_ENTRANCE_LOCK 'x'
#define MAP_KEY_LOCK      '*'


/*!
 * @brief Data structure to hold map-data.
 */
typedef struct
{
	RLgtApp*        gt_app;
	RLsoundContext* sound;
	RLrect          screen;
	RLrect          radar_screen;
	int*            image_index;
	int             level;
	int             show_radar_center;
	int             show_entrance_lock;
	int             show_key_lock;
	double          center_x;
	double          center_y;
	unsigned char   data[ MAP_ROW_NUM ][ MAP_COL_NUM ];
}
Map;


void map_init( Map* map, RLgtApp* app, RLsoundContext* sound, 
	       RLrect* screen, RLrect* radar_screen, int* image_index );
void map_update( Map* map, Entity* spaceship );
void map_draw( Map* map );
void map_draw_radar( Map* map );
int  map_load( Map* map, Entity* spaceship, RLlist* enemies, Entity* keys, int level );
int  map_check_and_load_datafile( char* file_name, unsigned char* buf );
int  map_check_and_save_datafile( char* infile, char* outfile );
int  map_get_current_level( Map* map );
int  map_is_movable( Map* map, RLrect* rect, double* vx, double* vy, unsigned char* type );
int  map_is_entrance_lock( unsigned char map_element );
void map_show_radar_center( Map* map, int flag );
void map_show_entrance_lock( Map* map, int flag );
void map_show_key_lock( Map* map, int flag );


#endif /* ___MAP_H_INCLUDED_ */

/* End of map.h */
