/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (firebomb) data and draws it onto the screen.
 *
 * "$Id: firebomb.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define FIREBOMB_WIDTH    10
#define FIREBOMB_HEIGHT   10
#define FIREBOMB_STRENGTH 15
#define FIREBOMB_VELOCITY 5.0


/*!
 * Initializes missile (firebomb) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
firebomb_init( Entity* firebomb )
{
	firebomb->width        = FIREBOMB_WIDTH;
	firebomb->height       = FIREBOMB_HEIGHT;
	firebomb->strength     = FIREBOMB_STRENGTH;
	firebomb->vmax         = ( FIREBOMB_VELOCITY / entity_get_fps_ratio() );
	firebomb->draw_func    = firebomb_draw;
}


/*!
 * Draws a missile (firebomb) onto the game screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
firebomb_draw( Entity* firebomb )
{
#define FIREBOMB_POINTS_NUM 13

	if ( firebomb->is_alive ) {
		const double points[ FIREBOMB_POINTS_NUM ][2] = {
			{   2.5,   5.0 },
			{   2.5,   2.5 },
			{   5.0,   2.5 },
			{   5.0, - 2.5 },
			{   2.5, - 2.5 },
			{   2.5, - 5.0 },
			{ - 2.5, - 5.0 },
			{ - 2.5, - 2.5 },
			{ - 5.0, - 2.5 },
			{ - 5.0,   2.5 },
			{ - 2.5,   2.5 },
			{ - 2.5,   5.0 },
			{   2.5,   5.0 }
		};

		Point converted[ FIREBOMB_POINTS_NUM ];
		int screen_x;
		int screen_y;
		int culling = 1;
		int i;

		SCREEN_POSITION( firebomb, screen_x, screen_y );

		for ( i = 0; i < FIREBOMB_POINTS_NUM; i ++ ) {
			converted[i].x = ( short )( screen_x + (
						    points[i][0] * cos( firebomb->prot ) -
						    points[i][1] * sin( firebomb->prot ) ) );

			converted[i].y = ( short )( screen_y - (
						    points[i][0] * sin( firebomb->prot ) +
						    points[i][1] * cos( firebomb->prot ) ) );

			if ( rlib_rect_within( &( firebomb->screen ), converted[i].x, converted[i].y ) ) {
				culling = 0;
			}
		}

		if ( culling ) {
			return;
		}

		rlib_gt_set_foreground_color( firebomb->gt_app, RL_GT_MAX_RGB, 0, 0 );
		rlib_gt_fill_polygon( firebomb->gt_app, converted, 
			   FIREBOMB_POINTS_NUM, RL_GT_POLYGON_CONVEX );
	}
}


/* End of firebomb.c */
