/*
 * Copyright (c) 2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of sound library using OSS ( Open Sound System ).
 *
 * $Id: RLoss.h,v 1.2 2006/10/09 09:10:16 ryo Exp $
 */

#ifndef ___RLOSS_H_INCLUDED_
#define ___RLOSS_H_INCLUDED_

#include <pthread.h>

#include "RLdsp.h"
#include "RLlist.h"


/*!
 * @brief Data structure to manage loaded wave data.
 */
typedef struct
{
	short* data;
	int length;
}
RLossWaveData;


/*!
 * @brief Data structure represents an item within play list.
 */
typedef struct
{
	int id;
	int wave_index;
	int loop;
	int current;
}
RLossPlayItem;


/*!
 * @brief Max wave data num that can hold within RLossContext;
 */
#define RL_OSS_MAX_WAVE_NUM 32


/*!
 * @brief Buffer size for writing to the device at one time.
 */
#define RL_OSS_BUFSIZE      1024


/*!
 * @brief Sound library context.
 */
typedef struct
{
	int initialized;
	int stopped;

	pthread_t thread_id;
	pthread_mutex_t mutex;

	int fd;
	RLdspPrms device_prev_params;
	short buffer[ RL_OSS_BUFSIZE / sizeof( short ) ];

	RLossWaveData waves[ RL_OSS_MAX_WAVE_NUM ];
	int num_of_waves;

	RLlist play_list;
	int next_play_id;
}
RLossContext;


int  rlib_oss_initialize( RLossContext* context, char* device_name );
int  rlib_oss_load_wave( RLossContext* context, char* wave_name );
int  rlib_oss_play( RLossContext* context, int id, int loop );
void rlib_oss_stop( RLossContext* context, int id );
void rlib_oss_stop_all( RLossContext* context );
void rlib_oss_shutdown( RLossContext* context );


#endif /* ___RLOSS_H_INCLUDED_ */

/* End of RLoss.h */
