/*
 * Copyright (c) 2002-2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of utility functions for handling RIFF / WAVE file.
 *
 * $Id: RLwave.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $
 */

#ifndef ___RLWAVE_H_INCLUDED_
#define ___RLWAVE_H_INCLUDED_


#include <stdio.h>


/*!
 * rlib_wave_open with read mode.
 */
#define RLWAVE_READ  0


/*!
 * rlib_wave_open with write mode.
 */
#define RLWAVE_WRITE 1


/*!
 * Byte length of wave header ( "WAVE" + "fmt " + sizeof( length of format data ) )
 */
#define RLWAVE_WAVHEAD_LENGTH  12

/*!
 * Byte length of format data struct.
 */
#define RLWAVE_FMTHEAD_LENGTH  18


/*!
 * Byte length of PCM data header ( "data" + sizeof( length of PCM data ) )
 */
#define RLWAVE_PCMHEAD_LENGTH   8


/*!
 * RIFF / WAVE file's fmt chunk information
 *
 * fp      - FILE pointer.<br>
 * is_pcm  - 1 if raw pcm format, else 0.<br>
 * channel - number of audio channel<br>
 * rate    - sampling rate, from 11025 Hz up to 44100 Hz<br>
 * bits    - sampling data bit size<br>
 * offset  - offset from the head of the file to PCM data.<br>
 * len     - length of PCM data.<br>
 */
typedef struct {
	FILE* fp;
	short is_pcm;
	short channel;
	int   rate;
	short bits;
	long  offset;
	int   len;
}
RLWAVE;


int  rlib_wave_open( RLWAVE* wavep, const char* filepath_ptr, int mode, int* err );
int  rlib_wave_read_header( RLWAVE* wavep, int* err );
int  rlib_wave_write_header( RLWAVE* wavep, int* err );
void rlib_wave_close( RLWAVE* wavep );


#endif /* ___RLWAVE_H_INCLUDED_ */

/* End of RLwave.h */
