/*
 * Copyright (c) 2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Sample application which explains how to use RLoss code.
 */

#include <stdio.h>
#include <stdlib.h>
#include "RLoss.h"


int 
main( int argc, char** argv )
{
	RLossContext context;
	char buf[32];
	int  command;
	int  i = 0;

	char* files[] = {
		"click.wav", 
		"damage.wav",
		"doughnut.wav",
		"esc.wav",
		"explosion.wav",
		"missile.wav",
		"pause.wav",
		"select.wav",
		"shot.wav",
		NULL
	};

	if ( argc != 2 ) {
		fprintf( stderr, "Specify wave file directory path.\n" );
		exit(1);
	}

	if ( rlib_oss_initialize( &context, "/dev/dsp" ) ) {
		perror( "rlib_oss_initialize" );
	}

	while ( 1 ) {
		char filepath[255];

		if ( files[i] == NULL ) {
			break;
		}

		snprintf( filepath, sizeof( filepath ), "%s/%s", argv[1], files[i ++ ] );
		rlib_oss_load_wave( &context, filepath );
	}

	while ( 1 ) {
		printf( " 1: play click.\n" );
		printf( " 2: play damage.\n" );
		printf( " 3: play doughnut.\n" );
		printf( " 4: play esc.\n" );
		printf( " 5: play explosion.\n" );
		printf( " 6: play missile.\n" );
		printf( " 7: play pause.\n" );
		printf( " 8: play select.\n" );
		printf( " 9: play shot.\n" );
		printf( "10: stop all.\n" );
		printf( "99: exit.\n" );
		printf( "command:?" );

		fgets( buf, sizeof( buf ), stdin );
		sscanf( buf, "%d", &command );

		if ( command <= 9 ) {
			rlib_oss_play( &context, command - 1, 1 );
		}
		else if ( command == 10 ) {
			rlib_oss_stop_all( &context );
		}
		else if ( command == 99 ) {
			break;
		}
	}

	rlib_oss_shutdown( &context );
	return 0;
}


/* End of oss_sample.c */
